==> georepo-server-2.6.1-sources.jar: de/narimo/georepo/server/repository/CommentRepository.java <==
package de.narimo.georepo.server.repository;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.narimo.commons.dto.geometa.User;
import de.narimo.commons.jdbc.JDBCConnectionJNDI;
import de.narimo.geocore.ws.repository.UserRepository;
import de.narimo.georepo.server.GeorepoConstants;
import de.narimo.georepo.server.api.comments.CommentOrLinkType;
import de.narimo.georepo.server.api.comments.Weblink;
import de.narimo.georepo.server.tools.AdminTools;
import de.narimo.georepo.server.tools.QueryCheck;
import de.narimo.georepo.server.tools.TableTools;

public class CommentRepository {

    /**
     * Checks, whether a comment table exists for a given layer id.
     * 
     * @param layerId
     * @return
     * @throws SQLException
     */
    public static boolean checkCommentsTableExists(int layerId) throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String imgTable = TableTools.getCommentTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT 1 FROM " + imgTable + ";";
            System.out.println(sql);

            jdbcData.executeQuery(sql);

            return true;
        } catch (Exception e) {
            if (e.getMessage().contains("does not exist")) {
                return false;
            }
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static boolean checkCommentsDiffTableExists(int layerId) throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String imgTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT 1 FROM " + imgTable + ";";
            System.out.println(sql);

            jdbcData.executeQuery(sql);

            return true;
        } catch (Exception e) {
            if (e.getMessage().contains("does not exist")) {
                return false;
            }
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Creates a table that stores comments related to a POI of the layer that this
     * table is related to.
     * 
     * @param layerId
     * @throws SQLException
     */
    public static void createCommentsTable(int layerId) throws SQLException {
        JDBCConnectionJNDI jdbcData = null;

        String cmtDataTable = TableTools.getCommentTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "CREATE TABLE public." + cmtDataTable + "("
                    + "id SERIAL PRIMARY KEY,"
                    + "gfid integer NOT NULL,"
                    + "comment text,"
                    + "description text,"
                    + "type text NOT NULL,"
                    + "insertedby integer NOT NULL,"
                    + "insertedat timestamp without time zone DEFAULT timezone('utc'::text, now()) NOT NULL"
                    + ");";

            System.out.println(sql);
            jdbcData.execute(sql);

        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Creates a comment diff table from the structure of an comment table. And adds
     * a grpstatus column.
     *
     * @param dataTable
     */
    public static void createCommentDiffTable(int layerId) throws SQLException {
        JDBCConnectionJNDI jdbcData = null;

        String commentDataTable = TableTools.getCommentTableName(layerId);
        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "CREATE TABLE public." + commentDiffTable + ""
                    + " (LIKE " + commentDataTable
                    + " INCLUDING DEFAULTS INCLUDING CONSTRAINTS INCLUDING INDEXES);"
                    + " ALTER TABLE " + commentDiffTable
                    + " ADD COLUMN " + GeorepoConstants.GRPSTATUSCOLUMN + " character varying(1) NOT NULL;";

            System.out.println(sql);
            jdbcData.execute(sql);

        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Checks, if a comment diff table exist for a given layer id.
     * 
     * @param layerId
     * @return
     * @throws SQLException
     */
    public static boolean checkCommentDiffTableExists(int layerId) throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT 1 FROM " + commentDiffTable + ";";
            System.out.println(sql);

            jdbcData.executeQuery(sql);

            return true;
        } catch (Exception e) {
            e.printStackTrace();
            if (e.getMessage().contains("does not exist")) {
                return false;
            }
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Inserts a new comment or weblink and returns its id.
     * 
     * @param layerId
     * @param userId
     * @param gfid
     * @return
     * @throws SQLException
     */
    public static int insertUnreviewedCommentOrWeblink(int layerId, Integer userId, int gfid, String commentOrWeblink,
            CommentOrLinkType commentOrLinkType)
            throws SQLException {

        if (userId == null) {
            throw new RuntimeException();
        }

        JDBCConnectionJNDI jdbcData = null;

        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "INSERT INTO " + commentDiffTable
                    + " (gfid, comment, insertedby, grpstatus, type) VALUES (?, ?, ?, ?, ?) RETURNING id;";
            System.out.println(sql);

            PreparedStatement ps = jdbcData.prepareStatement(sql);
            ps.setInt(1, gfid);
            ps.setString(2, commentOrWeblink);
            ps.setInt(3, userId);
            ps.setString(4, "n");
            ps.setString(5, commentOrLinkType.toString());
            ResultSet rs = ps.executeQuery();

            while (rs.next()) {
                return rs.getInt("id");
            }
            throw new RuntimeException("Could not insert comment or link.");

        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static List<Weblink> getFeatureComments(User requestingUser, String workspace, int layerId, int gfid,
            CommentOrLinkType commentOrLinkType)
            throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String commentTable = TableTools.getCommentTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT id, comment, description, insertedat, insertedby FROM " + commentTable
                    + " WHERE gfid = ? AND type = ?;";
            System.out.println(sql);

            PreparedStatement ps = jdbcData.prepareStatement(sql);
            ps.setInt(1, gfid);
            ps.setString(2, commentOrLinkType.toString());
            ResultSet rs = ps.executeQuery();

            List<Weblink> comments = new ArrayList<>();
            List<Integer> creators = new ArrayList<>();
            while (rs.next()) {
                int id = rs.getInt("id");
                String cmt = rs.getString("comment");
                String insertedat = rs.getString("insertedat");
                String description = rs.getString("description");
                int insertedby = rs.getInt("insertedby");
                Weblink comment = new Weblink();
                comment.setId(id);
                // comment.setComment(cmt);
                comment.setLink(cmt);
                comment.setDescription(description);
                comment.setCreatedat(insertedat);
                // this is the user id but needs to be transformed to a user name
                comment.setCreator(String.valueOf(insertedby));

                creators.add(insertedby);

                comments.add(comment);
            }

            List<User> users = UserRepository.getUsersById(creators);
            Map<Integer, User> userMap = new HashMap<Integer, User>();
            for (User user : users) {
                userMap.put(user.getId(), user);
            }

            for (Weblink comment : comments) {
                int userid = Integer.valueOf(comment.getCreator());
                String commentCreatorMail = userMap.get(userid).getEmail();

                comment.setCreator(commentCreatorMail.substring(0, commentCreatorMail.indexOf('@')));

                if (AdminTools.isWorkspaceAdmin(requestingUser.getId(), workspace)) {
                    comment.setCreatormail(commentCreatorMail);
                }
            }

            return comments;
        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static List<Weblink> getDiffFeatureComments(User requestingUser, String workspace, int layerId,
            CommentOrLinkType commentOrLinkType)
            throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT id, gfid, comment, description, insertedat, insertedby FROM " + commentDiffTable
                    + " WHERE type = ?;";
            System.out.println(sql);

            PreparedStatement ps = jdbcData.prepareStatement(sql);
            ps.setString(1, commentOrLinkType.toString());
            ResultSet rs = ps.executeQuery();

            List<Weblink> comments = new ArrayList<>();
            List<Integer> creators = new ArrayList<>();
            while (rs.next()) {
                int id = rs.getInt("id");
                int gfid = rs.getInt("gfid");
                String cmt = rs.getString("comment");
                String insertedat = rs.getString("insertedat");
                String description = rs.getString("description");
                int insertedby = rs.getInt("insertedby");
                Weblink comment = new Weblink();
                comment.setId(id);
                comment.setGfid(gfid);
                // comment.setComment(cmt);
                comment.setLink(cmt);
                comment.setDescription(description);
                comment.setCreatedat(insertedat);
                // this is the user id but needs to be transformed to a user name
                comment.setCreator(String.valueOf(insertedby));

                creators.add(insertedby);

                comments.add(comment);
            }

            List<User> users = UserRepository.getUsersById(creators);
            Map<Integer, User> userMap = new HashMap<Integer, User>();
            for (User user : users) {
                userMap.put(user.getId(), user);
            }

            for (Weblink comment : comments) {
                int userid = Integer.valueOf(comment.getCreator());
                String commentCreatorMail = userMap.get(userid).getEmail();

                comment.setCreator(commentCreatorMail.substring(0, commentCreatorMail.indexOf('@')));

                if (AdminTools.isWorkspaceAdmin(requestingUser.getId(), workspace)) {
                    comment.setCreatormail(commentCreatorMail);
                }
            }

            return comments;
        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static List<Weblink> getFeatureWeblinks(User requestingUser, String workspace, int layerId,
            int gfid)
            throws SQLException {

        return getFeatureComments(requestingUser, workspace, layerId, gfid, CommentOrLinkType.WEBLINK);
    }

    public static List<Weblink> getFeatureDiffWeblinks(User requestingUser, String workspace, int layerId)
            throws SQLException {

        return getDiffFeatureComments(requestingUser, workspace, layerId, CommentOrLinkType.WEBLINK);
    }

    /**
     * Accept a comment from a comments diff table.
     *
     * @param diffTable
     * @param dataTable
     * @param grpfid
     * @param features
     * @param userId
     */
    public static void acceptCommentOrWeblink(String commentsTable, String diffCommentsTable,
            int gfid, int diffCommentId) {

        QueryCheck.checkTableName(commentsTable);
        QueryCheck.checkDiffTableName(diffCommentsTable);

        JDBCConnectionJNDI jdbcData = null;

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String accept = "INSERT INTO " + commentsTable + " (comment,gfid,insertedby,insertedat,type) "
                    + "SELECT comment,gfid,insertedby,insertedat,type from " + diffCommentsTable + " WHERE gfid = "
                    + gfid + " AND id = " + diffCommentId + ";";

            accept += "DELETE FROM " + diffCommentsTable + " WHERE gfid = " + gfid + " AND id = " + diffCommentId + ";";

            jdbcData.execute(accept);

        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static void deleteCommentOrWeblink(String commentsTable, int gfid, int commentOrWeblinkId) {
        QueryCheck.checkTableName(commentsTable);

        JDBCConnectionJNDI jdbcData = null;

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String delete = "DELETE FROM " + commentsTable + " WHERE gfid = " + gfid + " AND id = " + commentOrWeblinkId
                    + ";";
            jdbcData.execute(delete);

        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }
}

==> georepo-server-2.7-sources.jar: de/narimo/georepo/server/repository/CommentRepository.java <==
package de.narimo.georepo.server.repository;

import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.narimo.commons.dto.User;
import de.narimo.commons.jdbc.JDBCConnectionJNDI;
import de.narimo.geocore.ws.repository.UserRepository;
import de.narimo.georepo.server.GeorepoConstants;
import de.narimo.georepo.server.api.comments.CommentOrLinkType;
import de.narimo.georepo.server.api.comments.Weblink;
import de.narimo.georepo.server.tools.AdminTools;
import de.narimo.georepo.server.tools.QueryCheck;
import de.narimo.georepo.server.tools.TableTools;

public class CommentRepository {

    /**
     * Checks, whether a comment table exists for a given layer id.
     * 
     * @param layerId
     * @return
     * @throws SQLException
     */
    public static boolean checkCommentsTableExists(int layerId) throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String cmtTable = TableTools.getCommentTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT 1 FROM " + cmtTable + ";";
            System.out.println(sql);

            jdbcData.executeQuery(sql);

            return true;
        } catch (Exception e) {
            if (e.getMessage().contains("does not exist")) {
                return false;
            }
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static boolean checkCommentsDiffTableExists(int layerId) throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String imgTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT 1 FROM " + imgTable + ";";
            System.out.println(sql);

            jdbcData.executeQuery(sql);

            return true;
        } catch (Exception e) {
            if (e.getMessage().contains("does not exist")) {
                return false;
            }
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Creates a table that stores comments related to a POI of the layer that this
     * table is related to.
     * 
     * @param layerId
     * @throws SQLException
     */
    public static void createCommentsTable(int layerId) throws SQLException {
        JDBCConnectionJNDI jdbcData = null;

        String cmtDataTable = TableTools.getCommentTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "CREATE TABLE public." + cmtDataTable + "("
                    + "id SERIAL PRIMARY KEY,"
                    + "gfid integer NOT NULL,"
                    + "comment text,"
                    + "description text,"
                    + "type text NOT NULL,"
                    + "insertedby integer NOT NULL,"
                    + "insertedat timestamp without time zone DEFAULT timezone('utc'::text, now()) NOT NULL"
                    + ");";

            System.out.println(sql);
            jdbcData.execute(sql);

        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Creates a comment diff table from the structure of an comment table. And adds
     * a grpstatus column.
     *
     * @param dataTable
     */
    public static void createCommentDiffTable(int layerId) throws SQLException {
        JDBCConnectionJNDI jdbcData = null;

        String commentDataTable = TableTools.getCommentTableName(layerId);
        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "CREATE TABLE public." + commentDiffTable + ""
                    + " (LIKE " + commentDataTable
                    + " INCLUDING DEFAULTS INCLUDING CONSTRAINTS INCLUDING INDEXES);"
                    + " ALTER TABLE " + commentDiffTable
                    + " ADD COLUMN " + GeorepoConstants.GRPSTATUSCOLUMN + " character varying(1) NOT NULL;";

            System.out.println(sql);
            jdbcData.execute(sql);

        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Checks, if a comment diff table exist for a given layer id.
     * 
     * @param layerId
     * @return
     * @throws SQLException
     */
    public static boolean checkCommentDiffTableExists(int layerId) throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT 1 FROM " + commentDiffTable + ";";
            System.out.println(sql);

            jdbcData.executeQuery(sql);

            return true;
        } catch (Exception e) {
            e.printStackTrace();
            if (e.getMessage().contains("does not exist")) {
                return false;
            }
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    /**
     * Inserts a new comment or weblink and returns its id.
     * 
     * @param layerId
     * @param userId
     * @param gfid
     * @return
     * @throws SQLException
     */
    public static int insertUnreviewedCommentOrWeblink(int layerId, Integer userId, int gfid, String commentOrWeblink,
            CommentOrLinkType commentOrLinkType, String description)
            throws SQLException {

        if (userId == null) {
            throw new RuntimeException();
        }

        JDBCConnectionJNDI jdbcData = null;

        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "INSERT INTO " + commentDiffTable
                    + " (gfid, comment, insertedby, grpstatus, type, description) VALUES (?, ?, ?, ?, ?, ?) RETURNING id;";
            System.out.println(sql);

            PreparedStatement ps = jdbcData.prepareStatement(sql);
            ps.setInt(1, gfid);
            ps.setString(2, commentOrWeblink);
            ps.setInt(3, userId);
            ps.setString(4, "n");
            ps.setString(5, commentOrLinkType.toString());
            ps.setString(6, description);
            ResultSet rs = ps.executeQuery();

            if (rs.next()) {
                return rs.getInt("id");
            }
            throw new RuntimeException("Could not insert comment or link.");

        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static List<Weblink> getFeatureComments(User requestingUser, String workspace, int layerId, int gfid,
            CommentOrLinkType commentOrLinkType)
            throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String commentTable = TableTools.getCommentTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT id, comment, description, insertedat, insertedby FROM " + commentTable
                    + " WHERE gfid = ? AND type = ?;";
            System.out.println(sql);

            PreparedStatement ps = jdbcData.prepareStatement(sql);
            ps.setInt(1, gfid);
            ps.setString(2, commentOrLinkType.toString());
            ResultSet rs = ps.executeQuery();

            List<Weblink> comments = new ArrayList<>();
            List<Integer> creators = new ArrayList<>();
            while (rs.next()) {
                int id = rs.getInt("id");
                String cmt = rs.getString("comment");
                String insertedat = rs.getString("insertedat");
                String description = rs.getString("description");
                int insertedby = rs.getInt("insertedby");
                Weblink comment = new Weblink();
                comment.setId(id);
                // comment.setComment(cmt);
                comment.setLink(cmt);
                comment.setDescription(description);
                comment.setCreatedat(insertedat);
                // this is the user id but needs to be transformed to a user name
                comment.setCreator(String.valueOf(insertedby));

                creators.add(insertedby);

                comments.add(comment);
            }

            List<User> users = UserRepository.getUsersById(creators);
            Map<Integer, User> userMap = new HashMap<Integer, User>();
            for (User user : users) {
                userMap.put(user.getId(), user);
            }

            for (Weblink comment : comments) {
                int userid = Integer.valueOf(comment.getCreator());
                String commentCreatorMail = userMap.get(userid).getEmail();

                comment.setCreator(commentCreatorMail.substring(0, commentCreatorMail.indexOf('@')));

                if (AdminTools.isWorkspaceAdmin(requestingUser.getId(), workspace)) {
                    comment.setCreatormail(commentCreatorMail);
                }
            }

            return comments;
        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static List<Weblink> getDiffFeatureComments(User requestingUser, String workspace, int layerId,
            CommentOrLinkType commentOrLinkType)
            throws SQLException {

        JDBCConnectionJNDI jdbcData = null;

        String commentDiffTable = TableTools.getCommentDiffTableName(layerId);

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String sql = "SELECT id, gfid, comment, description, insertedat, insertedby FROM " + commentDiffTable
                    + " WHERE type = ?;";
            System.out.println(sql);

            PreparedStatement ps = jdbcData.prepareStatement(sql);
            ps.setString(1, commentOrLinkType.toString());
            ResultSet rs = ps.executeQuery();

            List<Weblink> comments = new ArrayList<>();
            List<Integer> creators = new ArrayList<>();
            while (rs.next()) {
                int id = rs.getInt("id");
                int gfid = rs.getInt("gfid");
                String cmt = rs.getString("comment");
                String insertedat = rs.getString("insertedat");
                String description = rs.getString("description");
                int insertedby = rs.getInt("insertedby");
                Weblink comment = new Weblink();
                comment.setId(id);
                comment.setGfid(gfid);
                // comment.setComment(cmt);
                comment.setLink(cmt);
                comment.setDescription(description);
                comment.setCreatedat(insertedat);
                // this is the user id but needs to be transformed to a user name
                comment.setCreator(String.valueOf(insertedby));

                creators.add(insertedby);

                comments.add(comment);
            }

            List<User> users = UserRepository.getUsersById(creators);
            Map<Integer, User> userMap = new HashMap<Integer, User>();
            for (User user : users) {
                userMap.put(user.getId(), user);
            }

            for (Weblink comment : comments) {
                int userid = Integer.valueOf(comment.getCreator());
                String commentCreatorMail = userMap.get(userid).getEmail();

                comment.setCreator(commentCreatorMail.substring(0, commentCreatorMail.indexOf('@')));

                if (AdminTools.isWorkspaceAdmin(requestingUser.getId(), workspace)) {
                    comment.setCreatormail(commentCreatorMail);
                }
            }

            return comments;
        } catch (Exception e) {
            e.printStackTrace();
            throw new SQLException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static List<Weblink> getFeatureWeblinks(User requestingUser, String workspace, int layerId,
            int gfid)
            throws SQLException {

        return getFeatureComments(requestingUser, workspace, layerId, gfid, CommentOrLinkType.WEBLINK);
    }

    public static List<Weblink> getFeatureDiffWeblinks(User requestingUser, String workspace, int layerId)
            throws SQLException {

        return getDiffFeatureComments(requestingUser, workspace, layerId, CommentOrLinkType.WEBLINK);
    }

    /**
     * Accept a comment from a comments diff table.
     *
     * @param diffTable
     * @param dataTable
     * @param grpfid
     * @param features
     * @param userId
     */
    public static void acceptCommentOrWeblink(String commentsTable, String diffCommentsTable,
            int gfid, int diffCommentId) {

        QueryCheck.checkTableName(commentsTable);
        QueryCheck.checkDiffTableName(diffCommentsTable);

        JDBCConnectionJNDI jdbcData = null;

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String accept = "INSERT INTO " + commentsTable + " (comment,gfid,insertedby,insertedat,type,description) "
                    + "SELECT comment,gfid,insertedby,insertedat,type,description from " + diffCommentsTable
                    + " WHERE gfid = " + gfid + " AND id = " + diffCommentId + ";";

            accept += "DELETE FROM " + diffCommentsTable + " WHERE gfid = " + gfid + " AND id = " + diffCommentId + ";";

            jdbcData.execute(accept);

        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static void declineCommentOrWeblink(String diffCommentsTable,
            int gfid, int diffCommentId) {

        QueryCheck.checkDiffTableName(diffCommentsTable);

        JDBCConnectionJNDI jdbcData = null;

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String decline = "DELETE FROM " + diffCommentsTable + " WHERE gfid = " + gfid + " AND id = " + diffCommentId
                    + ";";
            jdbcData.execute(decline);

        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }

    public static void deleteCommentOrWeblink(String commentsTable, int gfid, int commentOrWeblinkId) {
        QueryCheck.checkTableName(commentsTable);

        JDBCConnectionJNDI jdbcData = null;

        try {
            jdbcData = new JDBCConnectionJNDI("jdbc/georepoDataResource");

            String delete = "DELETE FROM " + commentsTable + " WHERE gfid = " + gfid + " AND id = " + commentOrWeblinkId
                    + ";";
            jdbcData.execute(delete);

        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException(e);
        } finally {
            if (jdbcData != null) {
                jdbcData.closeAll();
                jdbcData = null;
            }
        }
    }
}
